marktools.StemTremolo
=====================

.. inheritance-diagram:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo
   :private-bases:

.. autoclass:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.format

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.tremolo_flags

Methods
-------

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.attach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.detach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__eq__

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__str__
